package;

import haxe.Timer;

import js.Dom;
import js.JQuery;
import js.Lib;

class Slider {

	private var _timer:Timer;
	private var _timerSpeed:Int;
	private var _countTimer:Int;
	private var _timerIsRunning:Bool;

	private var _jqSlider:JQuery;
	private var _jqAnimate:JQuery;
	private var _jqAnimateUlLi:JQuery;

	private var _nbrElements:Int;
	private var _elementWidth:Int;
	private var _sliderWidth:Int;
	private var _animateWidth:Int;
	private var _margin:Int;

	static function main () {
		
		new JQuery (Lib.document).ready(function(evt) {
			
			new Slider();
		});
	}

	public function new() {

		_jqSlider = new JQuery('#slider');
		_jqAnimate = new JQuery('#animate');
		_jqAnimateUlLi = new JQuery('#animate ul li');

		// required by Chrome for the width() function
		Lib.window.onload = _onload;
		
		Lib.window.onresize = _onresize;
	}

	private function _onload(evt:Event):Void {

		_nbrElements = _jqAnimateUlLi.length;

		_jqSlider.css("height", Std.string(new JQuery('#slider ul li').height()) + "px");

		_elementWidth = _jqAnimateUlLi.width();
		_animateWidth = _elementWidth * _nbrElements;
		new JQuery("#animate ul").width(_animateWidth);

		_onresize();

		_timerSpeed = 5000;
		_countTimer = 0;
		_timer = new Timer(_timerSpeed);
		_timer.run = _tick;
		_timerIsRunning = true;

		Lib.document.onkeyup = _onkeypress;

		_jqSlider.prepend('<input class="carousel-previous" type="button" value="Previous">');
		_jqSlider.append('<input class="carousel-next" type="button" value="Next">');

		new JQuery('.carousel-previous').click(function(evt) {
			
			_moveLeft();

			if (_timerIsRunning)
				_timerIsRunning = false;
		});

		new JQuery('.carousel-next').click(function(evt) {

			_moveRight();

			if (_timerIsRunning)
				_timerIsRunning = false;
		});
	}

	private function _onresize(?evt:Event):Void {

		_sliderWidth = _jqSlider.width();

		// bitwise operator FTW !
		_margin = Std.int(_sliderWidth - _elementWidth >> 1);

		_jqAnimateUlLi.css("margin-left", Std.string(_margin) + "px");
	}

	private function _tick():Void {

		if (_timerIsRunning)
			_moveRight();
	}

	private function _onkeypress(evt:Event):Void {

		if (evt.keyCode == 39)
			_moveRight();

		if (evt.keyCode == 37)
			_moveLeft();
	}

	private function _moveRight():Void {

		//pre incrementation FTW !
		if (++_countTimer == _nbrElements) {

			_jqAnimate.animate({left: 0});

			_countTimer = 0;

		} else {
			_jqAnimate.animate({left: '-=' + Std.string(_elementWidth + _margin) + "px"});
		}
	}

	private function _moveLeft():Void {

		//post incrementation FTW !
		if (_countTimer-- != 0) {

			_jqAnimate.animate({left: '+=' + Std.string(_elementWidth + _margin) + "px"});

		} else {

			_jqAnimate.animate({left: '-=' + Std.string((_elementWidth + _margin) * (_nbrElements - 1)) + "px"});

			_countTimer = _nbrElements - 1;
		}
	}
}